@@ -23,7 +23,7 @@ via SSH.
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 __docformat__ = 'reStructuredText'
-__version__ = '2.1.3 version (SVN $Revision: 3728 $)'
+__version__ = '2.1.4 version (SVN $Revision: 3953 $)'
 
 
 import os
@@ -557,11 +557,14 @@ class SshTransport(Transport):
         """
         gc3libs.log.info(
             "Closing SshTransport to host '%s'... " % self.remote_frontend)
-
-        if self.sftp is not None:
+        if self.sftp is not None and self.sftp.get_channel() is not None:
             self.sftp.close()
-        if self.ssh is not None:
+            gc3libs.log.info("... sftp connection to '%s' closed",
+                             self.remote_frontend)
+        if self.ssh is not None and self.ssh.get_transport() is not None:
             self.ssh.close()
+            gc3libs.log.info("... ssh connection to '%s' closed",
+                             self.remote_frontend)
         self._is_open = False
         # gc3libs.log.debug("Closed SshTransport to host '%s'"
         # % self.remote_frontend)
